;**************************************************************************
;* FileName	: ADC.INC
;* Date 	: 10.10.2002
;* File version : v1.01
;*
;* Author	: MIKO, Imre
;* Company	:
;* Homepage	: http://majki.fw.hu
;* E-mail	: majki@fw.hu
;*
;*-------------------------------------------------------------------------
;*
;* Description	: Functions for the A/D converter module
;*		  ======================================
;*		  AD_startconv
;*		  AD_endconv
;*
;*-------------------------------------------------------------------------
;* Needed defines and includes in main-modul:
;*
;* xtal_freq	EQU	4000000	  	; crystal frequency
;* core_freq	EQU	xtal_freq/4	; core operating frequency
;* 
;*	include "..\modules\wait.mac"
;*	include "..\modules\wait.inc"
;*
;*-------------------------------------------------------------------------
;* Other possible defines in main-modul:
;*
;* #define	DEBUG			; for some debug message
;* #define	AD_WITH_ANSEL		; for device with ANSEL register
;*
;**************************************************************************
;* Revision History:
;*
;* 1.00	  17/09/2001 	Initial Release
;* 1.01   10/10/2002	- reformatting source
;*			- support for newer ADs (PIC16F87xA and PIC12F675)
;*
;**************************************************************************

;***** VARIABLES **********************************************************

	cblock

	endc



	#ifdef INC_ADC

;***** AD_startconv *******************************************************
;* Start an A/D conversion
;* Input : W <- channel			; AD_CH0 ... AD_CH7
;* Output: -				;
;* Clock : AD_TACQ
;**************************************************************************
AD_startconv	iorlw	(AD_CLK1)
		movwf	ADCON0
		WAIT	AD_TACQ,0
		bsf	ADCON0, GO
		return



;***** AD_endconv *********************************************************
;* Wait until end of the A/D conversion
;* Input : -				;
;* Output: ADRES			; result of the conversion (8 bit A/D)
;*	   ADRESH:ADRESL		; result of the conversion (>8 bit A/D)
;* Clock : 2*AD_TAD
;**************************************************************************
AD_endconv	btfsc	ADCON0, GO
		goto	AD_endconv
		WAIT	2*AD_TAD,2
		return


	#endif
;**************************************************************************

